ErrorMessages class
Constructors
- ErrorMessages(Messages _parent)
-
const
Properties
- atLeastOneCharType → String
-
"At least one character type must be selected"no setter - characterPoolEmpty → String
-
"Character pool cannot be empty"no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- invalidFormat → String
-
"invalid format"no setter - invalidLength → String
-
"invalid length"no setter - lengthNonNegative → String
-
"Length must be non-negative"no setter - maxGenerationAttemptsPositive → String
-
"maxGenerationAttempts must be greater than 0"no setter - policyMinExceedsMax → String
-
"PasswordPolicy minLength cannot exceed maxLength"no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedCharSetsNotEmpty → String
-
"Selected character sets must not be empty"no setter - wordCountExceedsWordlist → String
-
"Word count exceeds wordlist size when duplicates are disabled"no setter - wordCountPositive → String
-
"Word count must be greater than 0"no setter - wordlistEmpty → String
-
"Wordlist must not be empty"no setter - wordlistHasEmptyWords → String
-
"Wordlist must not contain empty words"no setter
Methods
-
maxAttemptsExceeded(
int maxAttempts) → String -
"Unable to generate a strong password within $maxAttempts attempts." -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
passwordLengthMin(
int min) → String -
"Password length must be at least $min" -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited